@@ -2,7 +2,7 @@ context("Probability density")
 
 expect_traces <- function(gg, n.traces, name) {
   stopifnot(is.numeric(n.traces))
-  L <- save_outputs(gg, paste0("density-", name))
+  L <- expect_doppelganger_built(gg, paste0("density-", name))
   all.traces <- L$data
   no.data <- sapply(all.traces, function(tr) {
     is.null(tr[["x"]]) && is.null(tr[["y"]])
